==> org.eclipse.incquery.uml.source_1.0.0.201506021440.jar: org/eclipse/incquery/uml/derivedfeatures/PropertyIsCompositeMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.PropertyIsCompositeQuerySpecification;
import org.eclipse.uml2.uml.Property;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.propertyIsComposite pattern,
 * to be used in conjunction with {@link PropertyIsCompositeMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see PropertyIsCompositeMatcher
 * @see PropertyIsCompositeProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class PropertyIsCompositeMatch extends BasePatternMatch {
  private Property fProperty;
  
  private Boolean fIsComposite;
  
  private static List<String> parameterNames = makeImmutableList("property", "isComposite");
  
  private PropertyIsCompositeMatch(final Property pProperty, final Boolean pIsComposite) {
    this.fProperty = pProperty;
    this.fIsComposite = pIsComposite;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("property".equals(parameterName)) return this.fProperty;
    if ("isComposite".equals(parameterName)) return this.fIsComposite;
    return null;
  }
  
  public Property getProperty() {
    return this.fProperty;
  }
  
  public Boolean getIsComposite() {
    return this.fIsComposite;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("property".equals(parameterName) ) {
    	this.fProperty = (org.eclipse.uml2.uml.Property) newValue;
    	return true;
    }
    if ("isComposite".equals(parameterName) ) {
    	this.fIsComposite = (java.lang.Boolean) newValue;
    	return true;
    }
    return false;
  }
  
  public void setProperty(final Property pProperty) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fProperty = pProperty;
  }
  
  public void setIsComposite(final Boolean pIsComposite) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fIsComposite = pIsComposite;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.propertyIsComposite";
  }
  
  @Override
  public List<String> parameterNames() {
    return PropertyIsCompositeMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fProperty, fIsComposite};
  }
  
  @Override
  public PropertyIsCompositeMatch toImmutable() {
    return isMutable() ? newMatch(fProperty, fIsComposite) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"property\"=" + prettyPrintValue(fProperty) + ", ");
    
    result.append("\"isComposite\"=" + prettyPrintValue(fIsComposite)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fProperty == null) ? 0 : fProperty.hashCode());
    result = prime * result + ((fIsComposite == null) ? 0 : fIsComposite.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof PropertyIsCompositeMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    PropertyIsCompositeMatch other = (PropertyIsCompositeMatch) obj;
    if (fProperty == null) {if (other.fProperty != null) return false;}
    else if (!fProperty.equals(other.fProperty)) return false;
    if (fIsComposite == null) {if (other.fIsComposite != null) return false;}
    else if (!fIsComposite.equals(other.fIsComposite)) return false;
    return true;
  }
  
  @Override
  public PropertyIsCompositeQuerySpecification specification() {
    try {
    	return PropertyIsCompositeQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static PropertyIsCompositeMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pProperty the fixed value of pattern parameter property, or null if not bound.
   * @param pIsComposite the fixed value of pattern parameter isComposite, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static PropertyIsCompositeMatch newMutableMatch(final Property pProperty, final Boolean pIsComposite) {
    return new Mutable(pProperty, pIsComposite);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pProperty the fixed value of pattern parameter property, or null if not bound.
   * @param pIsComposite the fixed value of pattern parameter isComposite, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static PropertyIsCompositeMatch newMatch(final Property pProperty, final Boolean pIsComposite) {
    return new Immutable(pProperty, pIsComposite);
  }
  
  private static final class Mutable extends PropertyIsCompositeMatch {
    Mutable(final Property pProperty, final Boolean pIsComposite) {
      super(pProperty, pIsComposite);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends PropertyIsCompositeMatch {
    Immutable(final Property pProperty, final Boolean pIsComposite) {
      super(pProperty, pIsComposite);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}

==> org.eclipse.incquery.uml.source_1.2.0.201602080945.jar: org/eclipse/incquery/uml/derivedfeatures/PropertyIsCompositeMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.PropertyIsCompositeQuerySpecification;
import org.eclipse.uml2.uml.Property;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.propertyIsComposite pattern,
 * to be used in conjunction with {@link PropertyIsCompositeMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see PropertyIsCompositeMatcher
 * @see PropertyIsCompositeProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class PropertyIsCompositeMatch extends BasePatternMatch {
  private Property fProperty;
  
  private Boolean fIsComposite;
  
  private static List<String> parameterNames = makeImmutableList("property", "isComposite");
  
  private PropertyIsCompositeMatch(final Property pProperty, final Boolean pIsComposite) {
    this.fProperty = pProperty;
    this.fIsComposite = pIsComposite;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("property".equals(parameterName)) return this.fProperty;
    if ("isComposite".equals(parameterName)) return this.fIsComposite;
    return null;
  }
  
  public Property getProperty() {
    return this.fProperty;
  }
  
  public Boolean getIsComposite() {
    return this.fIsComposite;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("property".equals(parameterName) ) {
    	this.fProperty = (Property) newValue;
    	return true;
    }
    if ("isComposite".equals(parameterName) ) {
    	this.fIsComposite = (Boolean) newValue;
    	return true;
    }
    return false;
  }
  
  public void setProperty(final Property pProperty) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fProperty = pProperty;
  }
  
  public void setIsComposite(final Boolean pIsComposite) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fIsComposite = pIsComposite;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.propertyIsComposite";
  }
  
  @Override
  public List<String> parameterNames() {
    return PropertyIsCompositeMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fProperty, fIsComposite};
  }
  
  @Override
  public PropertyIsCompositeMatch toImmutable() {
    return isMutable() ? newMatch(fProperty, fIsComposite) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"property\"=" + prettyPrintValue(fProperty) + ", ");
    
    result.append("\"isComposite\"=" + prettyPrintValue(fIsComposite)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fProperty == null) ? 0 : fProperty.hashCode());
    result = prime * result + ((fIsComposite == null) ? 0 : fIsComposite.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof PropertyIsCompositeMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    PropertyIsCompositeMatch other = (PropertyIsCompositeMatch) obj;
    if (fProperty == null) {if (other.fProperty != null) return false;}
    else if (!fProperty.equals(other.fProperty)) return false;
    if (fIsComposite == null) {if (other.fIsComposite != null) return false;}
    else if (!fIsComposite.equals(other.fIsComposite)) return false;
    return true;
  }
  
  @Override
  public PropertyIsCompositeQuerySpecification specification() {
    try {
    	return PropertyIsCompositeQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static PropertyIsCompositeMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pProperty the fixed value of pattern parameter property, or null if not bound.
   * @param pIsComposite the fixed value of pattern parameter isComposite, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static PropertyIsCompositeMatch newMutableMatch(final Property pProperty, final Boolean pIsComposite) {
    return new Mutable(pProperty, pIsComposite);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pProperty the fixed value of pattern parameter property, or null if not bound.
   * @param pIsComposite the fixed value of pattern parameter isComposite, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static PropertyIsCompositeMatch newMatch(final Property pProperty, final Boolean pIsComposite) {
    return new Immutable(pProperty, pIsComposite);
  }
  
  private static final class Mutable extends PropertyIsCompositeMatch {
    Mutable(final Property pProperty, final Boolean pIsComposite) {
      super(pProperty, pIsComposite);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends PropertyIsCompositeMatch {
    Immutable(final Property pProperty, final Boolean pIsComposite) {
      super(pProperty, pIsComposite);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}
